@@ -6,6 +6,7 @@ from conan.tools.cmake.cmakedeps import FIND_MODE_NONE, FIND_MODE_CONFIG, FIND_M
 from conan.tools.cmake.cmakedeps.templates import CMakeDepsFileTemplate
 from conan.errors import ConanException
 from conan.internal.api.install.generators import relativize_path
+from conan.tools.cmake.utils import cmake_escape_value
 
 """
 
@@ -23,7 +24,8 @@ class ConfigDataTemplate(CMakeDepsFileTemplate):
         if self.arch:
             data_fname += "-{}".format(self.arch)
         data_fname += "-data.cmake"
-        return data_fname
+        # https://github.com/conan-io/conan/issues/17009
+        return data_fname.replace("|", "_")
 
     @property
     def _build_modules_activated(self):
@@ -267,7 +269,7 @@ class ConfigDataTemplate(CMakeDepsFileTemplate):
         return ret
 
 
-class _TargetDataContext(object):
+class _TargetDataContext:
 
     def __init__(self, cpp_info, pfolder_var_name, package_folder, require, library_type,
                  is_host_windows, conanfile, cmakedeps, comp_name=None):
@@ -295,15 +297,12 @@ class _TargetDataContext(object):
 
         def join_flags(separator, values):
             # Flags have to be escaped
-            ret = separator.join(v.replace('\\', '\\\\').replace('$', '\\$').replace('"', '\\"')
-                                 for v in values)
+            ret = separator.join(cmake_escape_value(v) for v in values)
             return ret
 
         def join_defines(values, prefix=""):
             # Defines have to be escaped, included spaces
-            return "\n\t\t\t".join('"%s%s"' % (prefix, v.replace('\\', '\\\\').replace('$', '\\$').
-                                   replace('"', '\\"'))
-                                   for v in values)
+            return "\n\t\t\t".join('"%s%s"' % (prefix, cmake_escape_value(v)) for v in values)
 
         self.include_paths = join_paths(cpp_info.includedirs)
         self.lib_paths = join_paths(cpp_info.libdirs)
@@ -356,8 +355,8 @@ class _TargetDataContext(object):
         if require and not require.run:
             self.bin_paths = ""
 
-        build_modules = cmakedeps.get_property("cmake_build_modules", conanfile) or []
+        build_modules = cmakedeps.get_property("cmake_build_modules", conanfile, check_type=list) or []
         self.build_modules_paths = join_paths(build_modules)
         # SONAME flag only makes sense for SHARED libraries
-        nosoname = cmakedeps.get_property("nosoname", conanfile, comp_name)
+        nosoname = cmakedeps.get_property("nosoname", conanfile, comp_name, check_type=bool)
         self.no_soname = str((nosoname if self.library_type == "SHARED" else False) or False).upper()
